import { SagaIterator } from 'redux-saga';
import { call, Effect, fork, put, takeEvery } from 'redux-saga/effects';

import Action from '@overflow/commons/redux/Action';
import SagaWatcher from '@overflow/commons/redux/saga/SagaWatcher';
import * as AsyncNotifyActions  from '@overflow/commons/redux/action/asyncNotify';
import AsyncNotifyPayload from '@overflow/commons/redux/payload/AsyncNotifyPayload';

import WebSocketRPC from '@overflow/commons/websocket/WebSocketRPC';

export class AsyncNotify implements SagaWatcher {
  private _webSocketRPC: WebSocketRPC;

  public setWebSocketRPC(webSocketRPC: WebSocketRPC): void {
    this._webSocketRPC = webSocketRPC;
  }

  private * request(webSocketRPC: WebSocketRPC, action: Action<AsyncNotifyPayload>): SagaIterator {
    const {service, method, args} = action.payload;
    yield call({context: webSocketRPC, fn: webSocketRPC.Notify}, `${service}.${method}`, args);
  }

  public * watch(): SagaIterator {
    yield takeEvery(AsyncNotifyActions.NOTIFY, this.request, this._webSocketRPC);
  }

}

export default AsyncNotify;
