
import * as React from 'react';
import { Button, Label } from 'semantic-ui-react';
import {
  BarChart, Bar, XAxis, YAxis, ZAxis, Cell, CartesianGrid, Tooltip, Legend, LineChart, Line,
  ResponsiveContainer, AreaChart, Area, PieChart, Pie, ReferenceLine, Brush, ComposedChart,
} from 'recharts';

export interface StateProps {
}

export interface DispatchProps {
}

export type Props = StateProps & DispatchProps;

export interface State {
  data: any;
}

export class TomcatMetric extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      data: undefined,
    };
  }

  public componentWillMount(): void {
    const data = [];
    for (let i = 0; i < 10; i++) {
      let maxThread = Math.floor(Math.random() * 100) + 10;
      let currentThread = Math.floor(Math.random() * 100) + 10;
      let busyThread = Math.floor(Math.random() * 100) + 10;

      let elem = { 'id': i, 'maxThread': maxThread, 'currentThread': currentThread, 'busyThread': busyThread };
      data[i] = elem;
    }

    this.setState({
      data: data,
    });
  }

  private showTooltipData = (data: any) => {
    if (data.active && data.payload) {
      return (
        <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
          <p>{`MaxThread : ${data.payload[0].payload.maxThread}`}</p>
          <p>{`CurrentThread : ${data.payload[0].payload.currentThread}`}</p>
          <p>{`BusyThread : ${data.payload[0].payload.busyThread}`}</p>
        </div>
      );
    }
    return null;
  }

  public render(): JSX.Element {
    const chartData = [
      { name: 'Used', value: 80, fill: '#8884d8', unit: '%' },
      { name: 'Free', value: 20, fill: '#82ca9d', unit: '%' },
    ];

    return (
      <div>
        <LineChart syncId='anyId' width={800} height={300}
                   data={this.state.data} margin={{ top: 5, right: 30, left: 20, bottom: 5 }} >
          <XAxis dataKey='id' />
          <YAxis dataKey='maxThread'/>
          {/* <CartesianGrid stroke='#ccc' /> */}
          <CartesianGrid strokeDasharray='3 3' />
          <Tooltip content={this.showTooltipData.bind(this)} />
          <Legend />
          <ReferenceLine y={9000} label='Warning' stroke='red' />
          <Line type='monotone' dataKey='currentThread' stroke='#8884d8' unit='jiffies' activeDot={{ r: 8 }} />
          <Line type='monotone' dataKey='busyThread' stroke='#42454a' unit='jiffies' activeDot={{ r: 8 }} />
        </LineChart>
      </div>
    );
  }
}
