import * as React from 'react';
import {
} from 'semantic-ui-react';

import {
  ResponsiveContainer, AreaChart, XAxis, YAxis, CartesianGrid, Tooltip, Legend, Area, Brush,
} from 'recharts';

export interface StateProps {
}

export interface DispatchProps {
  itemKey: string;
}

export type Props = StateProps & DispatchProps;

export interface State {
  data: any;
}

export class CPUChartLinux extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      data: undefined,
    };
  }

  public componentWillMount(): void {
    this.getData();
  }

  public render(): JSX.Element {
    return (
        <ResponsiveContainer width={'100%'} height={300}>
          <AreaChart syncId='sync' width={600} height={300}
            data={this.state.data} margin={{ top: 5, right: 30, left: 20, bottom: 5 }} >
            <XAxis dataKey='id' />
            <YAxis type='number' domain={[0, 100]} unit='%' />
            {/* <CartesianGrid stroke='#ccc' /> */}
            <CartesianGrid strokeDasharray='5 5' />
            <Tooltip content={this.showTooltipData.bind(this)} />
            <Legend />
            <Area type='monotone' dataKey={this.props.itemKey} stroke='#8884d8' fill='#82ca9d' unit='%' name='Usage' activeDot={{ r: 7 }} />
          </AreaChart>
        </ResponsiveContainer>
    );
  }

  private showTooltipData = (data: any) => {
    if (data.active && data.payload) {
      if (this.props.itemKey === 'cpu.usage.all') {
        return (
          <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
            <p><b>{`Usage : ${data.payload[0].value}%`}</b></p>
            <p>{`User : ${data.payload[0].payload['cpu.usage.user']}`}</p>
            <p>{`System : ${data.payload[0].payload['cpu.usage.system']}`}</p>
            <p>{`Nice : ${data.payload[0].payload['cpu.usage.nice']}`}</p>
            <p>{`Idle : ${data.payload[0].payload['cpu.usage.idle']}`}</p>
            <p>{`IOWait : ${data.payload[0].payload['cpu.usage.iowait']}`}</p>
            <p>{`IRQ : ${data.payload[0].payload['cpu.usage.irq']}`}</p>
            <p>{`SoftIRQ : ${data.payload[0].payload['cpu.usage.softirq']}`}</p>
            <p>{`Steal : ${data.payload[0].payload['cpu.usage.steal']}`}</p>
            <p>{`Guest : ${data.payload[0].payload['cpu.usage.guest']}`}</p>
            <p>{`GuestNice : ${data.payload[0].payload['cpu.usage.gnice']}`}</p>
          </div>
        );
      }else {
        return (
          <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
          <p><b>{`Usage : ${data.payload[0].value}%`}</b></p>
        </div>
        );
      }
    }
    return null;
  }

  private getData(): any {
    let raws = new Array();
    for (let i = 0; i < 20; i++) {
      let d = {'cpu.usage.gnice':'0', 'cpu.usage.guest':'0', 'cpu.usage.idle':'10871098',
      'cpu.usage.iowait':'188483', 'cpu.usage.irq':'0', 'cpu.usage.nice':'2600',
      'cpu.usage.softirq':'7233', 'cpu.usage.steal':'0', 'cpu.usage.sum':'11597797',
      'cpu.usage.system':'174526', 'cpu.usage.user':'353857',
      'date':'2017-10-31 19:30:24.238524358 +0900 KST'};
      raws[i] = d;
    }
    this.convertData(raws);
  }

  private convertData(raws: any): void {
    if(this.props.itemKey === 'cpu.usage.all') {
      this.convertToTotalUsage(raws);
    }else {
      this.convertToPartialUsage(raws);
    }
    this.setState({
      data: raws,
    });
  }

  private convertToTotalUsage(raws: any): any {
    for (let i = 0; i < raws.length; i++) {
      let raw = raws[i];
      let usage = 100 - (raw['cpu.usage.idle'] * 100 / raw['cpu.usage.sum']);
      raw['cpu.usage.all'] = usage.toFixed(2);
      raw.id = i;
    }
    return raws;
  }

  private convertToPartialUsage(raws: any): any {
    for (let i = 0; i < raws.length; i++) {
      let raw = raws[i];
      let usage = raw[this.props.itemKey] / raw['cpu.usage.sum'] * 100;
      raw[this.props.itemKey] = usage.toFixed(2);
      raw.id = i;
    }
    return raws;
  }
}

