import * as React from 'react';
import {
} from 'semantic-ui-react';
import {
  ResponsiveContainer, LineChart, XAxis, YAxis, CartesianGrid, Tooltip, Legend, Line, Brush,
} from 'recharts';
import * as _ from 'lodash';

export interface StateProps {
}

export interface DispatchProps {
  itemKey: string;
}

export type Props = StateProps & DispatchProps;

export interface State {
  data: any;
}

export class LoadChartLinux extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      data: undefined,
    };
  }

  public componentWillMount(): void {
    this.getData();
  }

  public render(): JSX.Element {
    return (
      <ResponsiveContainer width={'100%'} height={300}>
        <LineChart syncId='sync' width={800} height={300}
          data={this.state.data} margin={{ top: 5, right: 30, left: 20, bottom: 5 }} >
          <XAxis dataKey='id' />
          <YAxis type='number' domain={[0, 1]} />
          <CartesianGrid strokeDasharray='3 3' />
          <Tooltip />
          <Legend />
          <Line type='monotone' dataKey={'cpu.load.avg1'} stroke='#8884d8' activeDot={{ r: 8 }} />
          <Line type='monotone' dataKey={'cpu.load.avg5'} stroke='#d88884' activeDot={{ r: 8 }} />
          <Line type='monotone' dataKey={'cpu.load.avg15'} stroke='#8848d8' activeDot={{ r: 8 }} />
        </LineChart>
      </ResponsiveContainer>
    );
  }

  private showTooltipData = (data: any) => {
    if (data.active && data.payload) {
      if (this.props.itemKey === 'cpu.load.all') {
        return (
          <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
            <p><b>{`Usage : ${data.payload[0].value}%`}</b></p>
            <p>{`User : ${data.payload[0].payload['cpu.usage.user']}`}</p>
          </div>
        );
      } else {
        return (
          <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
            <p><b>{`Usage : ${data.payload[0].value}%`}</b></p>
          </div>
        );
      }
    }
    return null;
  }

  private getData(): any {
    setInterval(this.getNew, 5000);
    let raws = new Array();
    for (let i = 0; i < 10; i++) {
      let a = Math.random().toFixed(2);
      let b = Math.random().toFixed(2);
      let c = Math.random().toFixed(2);
      let d = {'cpu.load.avg1':a, 'cpu.load.avg5':b, 'cpu.load.avg15':c};
      raws[i] = d;
    }
    this.convertData(raws);
  }

  private id: number = 10;
  private getNew = () => {

    let data = _.clone(this.state.data);
    let a = Math.random().toFixed(2);
    let b = Math.random().toFixed(2);
    let c = Math.random().toFixed(2);

    let newData = {'id': this.id++, 'cpu.load.avg1':a, 'cpu.load.avg5':b, 'cpu.load.avg15': c};
    data.shift();
    data[data.length] = newData;
    this.setState({
      data: data,
    });
  }

  private convertData(raws: any): void {
    for (let i = 0; i < raws.length; i++) {
      let raw = raws[i];
      raw['cpu.load.avg1'] = Number(raw['cpu.load.avg1']);
      raw['cpu.load.avg5'] = Number(raw['cpu.load.avg5']);
      raw['cpu.load.avg15'] = Number(raw['cpu.load.avg15']);
      raw.id = i;
    }
    this.setState({
      data: raws,
    });
  }
}

