import * as React from 'react';
import {
} from 'semantic-ui-react';

import {
  ResponsiveContainer, AreaChart, XAxis, YAxis, CartesianGrid, Tooltip, Legend, Area, Brush,
} from 'recharts';

export interface StateProps {
}

export interface DispatchProps {
  itemKey: string;
}

export type Props = StateProps & DispatchProps;

export interface State {
  data: any;
}

export class MemChartLinux extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      data: undefined,
    };
  }

  public componentWillMount(): void {
    this.getData();
  }

  public render(): JSX.Element {
    let yAxis: JSX.Element = null;
    if (this.props.itemKey === 'mem.usage.all' || this.props.itemKey === 'mem.swap.usage.all') {
      yAxis = <YAxis type='number' domain={[0, 100]} unit='%' />;
    }else {
      yAxis = <YAxis type='number' domain={[0, 'auto']} unit='mb'/>;
    }
    return (
      <ResponsiveContainer width={'100%'} height={300}>
        <AreaChart syncId='sync' width={600} height={300}
          data={this.state.data} margin={{ top: 5, right: 30, left: 20, bottom: 5 }} >
          <XAxis dataKey='id' />
          {yAxis}
          <CartesianGrid strokeDasharray='5 5' />
          <Tooltip content={this.showTooltipData.bind(this)} />
          <Legend />
          <Area type='monotone' dataKey={this.props.itemKey} stroke='#8884d8' fill='#35344A' unit='%' name='Usage' activeDot={{ r: 7 }} />
        </AreaChart>
      </ResponsiveContainer>
    );
  }

  private showTooltipData = (data: any) => {
    if (data.active && data.payload) {
      if (this.props.itemKey === 'mem.usage.all') {
        return (
          <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
            <p><b>{`Usage : ${data.payload[0].value}%`}</b></p>
            <p>{`Total : ${data.payload[0].payload['mem.usage.total']} kb`}</p>
            <p>{`Free : ${data.payload[0].payload['mem.usage.free']} kb`}</p>
            <p>{`Available : ${data.payload[0].payload['mem.usage.available']} kb`}</p>
            <p>{`Buffers : ${data.payload[0].payload['mem.usage.buffers']} kb`}</p>
            <p>{`Cached : ${data.payload[0].payload['mem.usage.cached']} kb`}</p>
            <p>{`Swap Total : ${data.payload[0].payload['mem.swap.usage.total']} kb`}</p>
            <p>{`Swap Free : ${data.payload[0].payload['mem.swap.usage.free']} kb`}</p>
            <p>{`Swap Cached : ${data.payload[0].payload['mem.swap.usage.cached']} kb`}</p>
          </div>
        );
      } else if (this.props.itemKey === 'mem.swap.usage.all') {
        return (
          <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
            <p><b>{`Usage : ${data.payload[0].value}%`}</b></p>
            <p>{`Swap Total : ${data.payload[0].payload['mem.swap.usage.total']} kb`}</p>
            <p>{`Swap Free : ${data.payload[0].payload['mem.swap.usage.free']} kb`}</p>
            <p>{`Swap Cached : ${data.payload[0].payload['mem.swap.usage.cached']} kb`}</p>
          </div>
        );
      } else {
        return (
          <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
            <p><b>{`Usage : ${data.payload[0].value} mb`}</b></p>
          </div>
        );
      }
    }
    return null;
  }

  private getData(): any {
    let raws = new Array();
    for (let i = 0; i < 30; i++) {
      let d = {
        'mem.swap.usage.cached': '0', 'mem.swap.usage.free': '475916', 'mem.swap.usage.total': '785916',
        'mem.usage.available': '4606156', 'mem.usage.buffers': '86008', 'mem.usage.cached': '2170568',
        'mem.usage.free': '3409156', 'mem.usage.total': '8102908',
      };
      raws[i] = d;
    }
    this.convertData(raws);
  }

  private convertData(raws: any): void {
    if (this.props.itemKey === 'mem.usage.all') {
      this.convertToTotalUsage(raws);
    } else if (this.props.itemKey === 'mem.swap.usage.all') {
      this.convertToSwapTotalUsage(raws);
    } else {
      this.convertToPartialUsage(raws);
    }
    this.setState({
      data: raws,
    });
  }

  private convertToTotalUsage(raws: any): any {
    for (let i = 0; i < raws.length; i++) {
      let raw = raws[i];
      let used = raw['mem.usage.total'] - raw['mem.usage.free'] - raw['mem.usage.buffers'] - raw['mem.usage.cached'];
      let usage = used / raw['mem.usage.total'] * 100;
      raw['mem.usage.all'] = usage.toFixed(2);
      raw.id = i;
    }
    return raws;
  }

  private convertToSwapTotalUsage(raws: any): any {
    for (let i = 0; i < raws.length; i++) {
      let raw = raws[i];
      let used = raw['mem.swap.usage.total'] - raw['mem.swap.usage.free'] - raw['mem.swap.usage.cached'];
      let usage = Number(used / raw['mem.swap.usage.total'] * 100);
      raw['mem.swap.usage.all'] = usage.toFixed(2);
      raw.id = i;
    }
    return raws;
  }

  private convertToPartialUsage(raws: any): any {
    for (let i = 0; i < raws.length; i++) {
      let raw = raws[i];
      let usage = raw[this.props.itemKey] / 1000;
      raw[this.props.itemKey] = Number(usage.toFixed(0));
      raw.id = i;
    }
    return raws;
  }
}

