import * as React from 'react';
import {
} from 'semantic-ui-react';
import {
  ResponsiveContainer, LineChart, XAxis, YAxis, CartesianGrid, Tooltip, Legend, Line, Brush,
} from 'recharts';
import * as Utils from '@overflow/commons/util/Utils';


export interface StateProps {
}

export interface DispatchProps {
  itemKey: string;
}

export type Props = StateProps & DispatchProps;

export interface State {
  data: any;
}

export class NetworkChartLinux extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      data: undefined,
    };
  }

  public componentWillMount(): void {
    this.getData();
  }

  public render(): JSX.Element {
    let dataKey1: string = null;
    let dataKey2: string = null;

    if (Utils.compareBracketName(this.props.itemKey, 'net.transfer.err')) {
      dataKey1 = 'net.recv.err';
      dataKey2 = 'net.send.err';
    } else if (Utils.compareBracketName(this.props.itemKey, 'net.transfer.pps')) {
      dataKey1 = 'net.recv.pps';
      dataKey2 = 'net.send.pps';
    }else if (Utils.compareBracketName(this.props.itemKey, 'net.transfer.bps')) {
      dataKey1 = 'net.recv.bps';
      dataKey2 = 'net.send.bps';
    }
    return (
      <ResponsiveContainer width={'100%'} height={300}>
        <LineChart syncId='sync' width={800} height={300}
          data={this.state.data} margin={{ top: 5, right: 30, left: 20, bottom: 5 }} >
          <XAxis dataKey='id' />
          <YAxis type='number' domain={[0, 'auto']} />
          <CartesianGrid strokeDasharray='3 3' />
          <Tooltip />
          <Legend />
          <Line type='monotone' dataKey={dataKey1} stroke='#8884d8' activeDot={{ r: 8 }} />
          <Line type='monotone' dataKey={dataKey2} stroke='#d88884' activeDot={{ r: 8 }} />
        </LineChart>
      </ResponsiveContainer>
    );
  }

  private showTooltipData = (data: any) => {
    // if (data.active && data.payload) {
    //   if (this.props.itemKey === 'cpu.load.all') {
    //     return (
    //       <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
    //         <p><b>{`Usage : ${data.payload.value}%`}</b></p>
    //         <p>{`User : ${data.payload.payload['cpu.usage.user']}`}</p>
    //       </div>
    //     );
    //   } else {
    //     return (
    //       <div style={{ backgroundColor: 'white', opacity: 0.7, border: '1px solid black', padding: '4px' }}>
    //         <p><b>{`Usage : ${data.payload.value}%`}</b></p>
    //       </div>
    //     );
    //   }
    // }
    // return null;
  }

  private getData(): any {
    let raws = new Array();
    for (let i = 0; i < 10; i++) {
      let d = {
        'net.transfer.iface': 'enp0s3', 'net.transfer.recv_byte': '2306759',
        'net.transfer.recv_compressed': '0', 'net.transfer.recv_drop': '0', 'net.transfer.recv_err': '3',
        'net.transfer.recv_fifo': '0', 'net.transfer.recv_frame': '0', 'net.transfer.recv_multicast': '1',
        'net.transfer.recv_packet': '4663', 'net.transfer.send_byte': '1040131',
        'net.transfer.send_compressed': '0', 'net.transfer.send_drop': '0', 'net.transfer.send_err': '7',
        'net.transfer.send_fifo': '0', 'net.transfer.send_frame': '0', 'net.transfer.send_multicast': '0',
        'net.transfer.send_packet': '4016',
      };
      raws[i] = d;
    }
    this.convertData(raws);
  }

  private convertData(raws: any): void {
    for (let i = 0; i < raws.length; i++) {
      let raw = raws[i];
      if(Utils.compareBracketName(this.props.itemKey, 'net.transfer.err')) {
        this.calcErr(raw);
      }else if(Utils.compareBracketName(this.props.itemKey, 'net.transfer.pps')) {
        this.calcPPS(raw);
      }else if(Utils.compareBracketName(this.props.itemKey, 'net.transfer.bps')) {
        this.calcBPS(raw);
      }
    }
    this.setState({
      data: raws,
    });
  }

  private calcErr(raw: any): any {
    raw['net.recv.err'] = Number(raw['net.transfer.send_err']);
    raw['net.send.err'] = Number(raw['net.transfer.recv_err']);
    return raw;
  }

  private calcPPS(raw: any): any {
    let intervalSec = 5; // temporary
    let recvPrev = '3873'; // temporary
    let sendPrev = '3368'; // temporary

    let recvCurr = raw['net.transfer.recv_packet'];
    let sendCurr = raw['net.transfer.send_packet'];

    raw['net.recv.pps'] = (Number(recvCurr) - Number(recvPrev)) / intervalSec;
    raw['net.send.pps'] = (Number(sendCurr) - Number(sendPrev)) / intervalSec;
  }

  private calcBPS(raw: any): any {
    let intervalSec = 5; // temporary

    let recvPrev = '2106878'; // temporary
    let sendPrev = '1000197'; // temporary

    let recvCurr = raw['net.transfer.recv_byte']; // 2306759
    let sendCurr = raw['net.transfer.send_byte']; // 1040131

    raw['net.recv.bps'] = (Number(recvCurr) - Number(recvPrev)) / intervalSec;
    raw['net.send.bps'] = (Number(sendCurr) - Number(sendPrev)) / intervalSec;
  }
}

